@@ -12,6 +12,7 @@ bartMachine = function(X = NULL, y = NULL, Xy = NULL,
     debug_log = FALSE,
     run_in_sample = TRUE,
     s_sq_y = "mse", # "mse" or "var"
+	sig_sq_est = NULL,
     #  	print_tree_illustrations = FALSE, #this feature is deprecated, but we're leaving it in the code commented out for the intrepid user
     cov_prior_vec = NULL,
     use_missing_data = FALSE,
@@ -40,6 +41,7 @@ bartMachine = function(X = NULL, y = NULL, Xy = NULL,
 	    debug_log,
 	    run_in_sample,
 	    s_sq_y,
+		sig_sq_est,
 	    #print_tree_illustrations = FALSE
 	    cov_prior_vec,
 	    use_missing_data,
